@@ -484,7 +484,7 @@ def g_counter(data, arities, cols, weights=None):
 
 
 # Pearson's correlation test
-def cor_test(data, cols):
+def pearson_test(data, cols):
     data = pandas.DataFrame(data)
     if len(cols) == 2:
         return pg.partial_corr(data, cols[0], cols[1])['p-val'][0]
