@@ -6,8 +6,8 @@ import numpy as np
 import pandas
 
 pandas.options.mode.chained_assignment = None
-from .accessory import g_test, cor_test, find_causes, pairwise, dag2cpdag, independence_test, orient_v_structure, \
-    orient_propagation, to_bnlearn
+from .accessory import g_test, cor_test, find_causes, pairwise, dag2cpdag, orient_v_structure, orient_propagation, \
+    to_bnlearn
 from .score import local_score
 
 
@@ -499,11 +499,13 @@ def pc_stable(data, test='default', threshold=0.05, debug=False):
     '''
     if test == 'default':
         if all(data[var].dtype.name == 'category' for var in data):
-            test = 'g-test'
+            ci_test = g_test
         elif all(data[var].dtype.name != 'category' for var in data):
-            test = 'z-test'
+            ci_test = cor_test
         else:
             raise Exception('Mixed type of data is not supported yet.')
+    else:
+        ci_test = globals()[test]
     data, dc = pre_process(data)
     varnames = data.columns.tolist()
     if all(data[var].dtype.name == 'category' for var in data):
@@ -525,9 +527,9 @@ def pc_stable(data, test='default', threshold=0.05, debug=False):
                     pc_var = [v for v in pc_copy[var]]
                     pc_var.remove(adj)
                     for con in itertools.combinations(pc_var, l):
-                        cols = np.array([varnames.index(v) for v in [var, adj] + list(con)])
-                        test_result, p = independence_test(data, cols, test=test, varnames=varnames,
-                                                           threshold=threshold)
+                        cols = [varnames.index(v) for v in [var, adj] + list(con)]
+                        p = ci_test(data, cols)
+                        test_result = p > threshold
                         if test_result:
                             if debug:
                                 print(var + ' and ' + adj + ' are independent given ' + con + ', p value=' + p)
@@ -538,7 +540,7 @@ def pc_stable(data, test='default', threshold=0.05, debug=False):
                             break
         l += 1
     # orient v-structrues
-    cpdag = orient_v_structure(data, varnames, pc, sepset, test, threshold=threshold)
+    cpdag = orient_v_structure(data, varnames, pc, sepset, ci_test, threshold=threshold)
     # orientation propagation
     cpdag = orient_propagation(cpdag)
     # force undirected edges to be directed if its orientation causes either cycles or new v-structures (force them to form v-structures)
